.. _management_commands:

===================
Management Commands
===================


MySQL-specific management commands. These are automatically available with
your ``manage.py`` when you add ``django_mysql`` to your ``INSTALLED_APPS``.

.. toctree::
   :maxdepth: 1

   dbparams
   fix_datetime_columns
